@@ -1,5 +1,5 @@
 /*
- * $Id: sensor.h,v 1.5 2007/10/12 12:46:48 d1mag Exp $
+ * $Id: sensor.h,v 1.6 2008/01/04 16:07:48 d1mag Exp $
  *
  * temploggerd -- graph/log utility written for OWFS
  * Written 2005 Christian Magnusson
@@ -50,5 +50,8 @@ unsigned char sensor_id(struct sensor *s);
 void update_sensors(char *path);
 int nr_avail_sensors(void);
 int print_sensor(struct sensor *s);
+int owwire_write(char *path, char *file, char *value, int len);
+int owwire_read(char *path, char *file, char *buf, int len);
+int owwire_present(char *path);
 
 #endif
