@@ -1,5 +1,5 @@
 /*
- * $Id: util.h,v 1.1 2005/08/26 13:04:56 d1mag Exp $
+ * $Id: util.h,v 1.3 2008/01/04 16:07:48 d1mag Exp $
  *
  * temploggerd -- graph/log utility written for OWFS
  * Written 2005 Christian Magnusson
@@ -9,7 +9,9 @@
 #ifndef UTIL_H
 #define UTIL_H
 
+int replace_slash(char *s, char *d);
 int replace_space(char *s, char *d);
+int replace_space_dot(char *s, char *d);
 int remove_space(char *s, char *d);
 unsigned char char2hex(char x);
 void my_delay(unsigned long ms);
