@@ -31,6 +31,9 @@
 
 #define BUFSIZE 8192
 
+char owshell_path[FILENAME_LEN+1] = "";
+char owshell_params[FILENAME_LEN+1] = "";
+
 /*
   Try to restore average values in rrd-file when week,month,year
   data will be inserted
