@@ -1,5 +1,5 @@
 /*
- * $Id: config_var.c,v 1.7 2007/10/12 12:46:48 d1mag Exp $
+ * $Id: config_var.c,v 1.8 2007/12/29 08:21:21 d1mag Exp $
  *
  * temploggerd -- graph/log utility written for OWFS
  * Written 2005 Christian Magnusson
@@ -25,6 +25,8 @@
  */
 
 char owfs_dir[FILENAME_LEN+1];
+char owshell_path[FILENAME_LEN+1];
+char owshell_params[FILENAME_LEN+1];
 char www_dir[FILENAME_LEN+1];
 char base_dir[FILENAME_LEN+1];
 char rrdfile_path[FILENAME_LEN+1];
@@ -52,6 +54,8 @@ char **tmpl_files = NULL;
 struct config_vars conf[] = {
   {"config_file", config_file},
   {"owfs_dir", owfs_dir},
+  {"owshell_path", owshell_path},
+  {"owshell_params", owshell_params},
   {"rrdfile_path", rrdfile_path},
   {"rrdfile_default", rrdfile_default},
   {"rrdfile_description_default", rrdfile_description_default},
@@ -83,6 +87,8 @@ void set_defaults(void)
   backup_freq[0] = '\000';
   _backup_freq = 0;
   owfs_dir[0] = '\000';
+  owshell_path[0] = '\000';
+  owshell_params[0] = '\000';
   strcpy(tmp_file, "/tmp/temploggerd.tmp");
   strcpy(rrdtool, "rrdtool");
   add_new_sensor_script[0] = '\000';
