@@ -1,5 +1,5 @@
 /*
- * $Id: html.c,v 1.8 2007/08/19 19:14:41 d1mag Exp $
+ * $Id: html.c,v 1.10 2008/01/04 16:07:48 d1mag Exp $
  *
  * temploggerd -- graph/log utility written for OWFS
  * Written 2005 Christian Magnusson
@@ -465,7 +465,7 @@ int replace_tags(char *out_file, FILE *out, struct sensor *cur_sensor, char *tmp
 	  } else if(!strcasecmp(varname, "_location")) {
 	    char loc[LOCATION_LEN+1];
 	    if(cur_sensor) {
-	      replace_space(cur_sensor->location, loc);
+	      replace_space_dot(cur_sensor->location, loc);
 	      append_fwrite(out_file, loc, strlen(loc), 1, out);
 	    } else {
 	      append_fwrite(out_file, unknown_sensor, strlen(unknown_sensor), 1, out);
@@ -473,7 +473,7 @@ int replace_tags(char *out_file, FILE *out, struct sensor *cur_sensor, char *tmp
 	  } else if(!strcasecmp(varname, "_sensid")) {
 	    char id_[DEVICE_ID_LEN+1];
 	    if(cur_sensor) {
-	      replace_space(cur_sensor->id, id_);
+	      replace_space_dot(cur_sensor->id, id_);
 	      append_fwrite(out_file, id_, strlen(id_), 1, out);
 	    } else {
 	      append_fwrite(out_file, unknown_sensor, strlen(unknown_sensor), 1, out);
@@ -488,7 +488,9 @@ int replace_tags(char *out_file, FILE *out, struct sensor *cur_sensor, char *tmp
 	    }
 	  } else if(!strcasecmp(varname, "datafile_full")) {
 	    if(cur_sensor) {
-	      append_fwrite(out_file, cur_sensor->datafile, strlen(cur_sensor->datafile), 1, out);
+	      char datafile_without_slash[FILENAME_LEN+1];
+	      replace_slash(cur_sensor->datafile, datafile_without_slash);
+	      append_fwrite(out_file, datafile_without_slash, strlen(datafile_without_slash), 1, out);
 	    } else {
 	      append_fwrite(out_file, unknown_sensor, strlen(unknown_sensor), 1, out);
 	    }
@@ -497,8 +499,6 @@ int replace_tags(char *out_file, FILE *out, struct sensor *cur_sensor, char *tmp
 	    char datafile[FILENAME_LEN+1];
 	    char *lastslash;
 	    if(cur_sensor) {
-	      //filenames with spaces is not allowed right now.
-	      //replace_space(cur_sensor->datafile, datafile);
 	      strcpy(datafile, cur_sensor->datafile);
 	      if((lastslash = strrchr(datafile, '/')) == NULL)
 		lastslash = datafile;
@@ -624,13 +624,16 @@ int create_webpage_sensor(struct sensor *s)
     char datafile[FILENAME_LEN+1];
     char *ptr;
     replace_space(s->datafile, datafile);
-    if((ptr = strrchr(datafile, '/')) == NULL)
+    if((ptr = strrchr(datafile, '/')) == NULL) {
       ptr = datafile;
-    else
+    } else {
       ptr = &ptr[1];
+    }
     sprintf(file, "%s%s.%s.cgi", cgi_dir, s->id, ptr);
   } else {
-    sprintf(file, "%s%s.%s.cgi", cgi_dir, s->id, s->datafile);
+    char datafile_without_slash[FILENAME_LEN+1];
+    replace_slash(s->datafile, datafile_without_slash);
+    sprintf(file, "%s%s.%s.cgi", cgi_dir, s->id, datafile_without_slash);
   }
   if(s->ignored) {
     //printf("%s is ignored. don't create [%s]\n", s->id, file);
