@@ -1,5 +1,5 @@
 /*
- * $Id: temploggerd.c,v 1.12 2007/10/12 12:46:48 d1mag Exp $
+ * $Id: temploggerd.c,v 1.13 2007/12/29 08:21:21 d1mag Exp $
  *
  * temploggerd -- graph/log utility written for OWFS
  * Written 2005 Christian Magnusson
@@ -377,16 +377,21 @@ int main(int argc, char **argv)
     exit(0);
   }
 
-  if(!(found_fuse = find_fusedev(owfs_dir, device_path, uncached_device_path))) {
-    if(owfs_dir[0]) {
-      printf("Can't find owfs/fuse directory at [%s]\n", owfs_dir);
-    } else {
-      printf("Can't find owfs/fuse directory in /proc/mounts\n");
+  if(*owshell_path) {
+    strcpy(uncached_device_path, "/uncached/");
+    nr_sensors = owshell_scan_bus(uncached_device_path);
+  } else {
+    if(!(found_fuse = find_fusedev(owfs_dir, device_path, uncached_device_path))) {
+      if(owfs_dir[0]) {
+	printf("Can't find owfs/fuse directory at [%s]\n", owfs_dir);
+      } else {
+	printf("Can't find owfs/fuse directory in /proc/mounts\n");
+      }
+      exit(0);
     }
-    exit(0);
+    nr_sensors = scan_bus(uncached_device_path);
   }
 
-  nr_sensors = scan_bus(uncached_device_path);
   if(new_device_found) {
     new_device_found = 0;
     generate_templates = 1;
@@ -542,7 +547,11 @@ int main(int argc, char **argv)
       if(read_config_file(1) < 0) {
 	fprintf(stderr, "Error reading config-file\n");
       }
-      nr_sensors = scan_bus(uncached_device_path);
+      if(*owshell_path) {
+	nr_sensors = owshell_scan_bus(uncached_device_path);
+      } else {
+	nr_sensors = scan_bus(uncached_device_path);
+      }
       new_device_found = 0;
       update_sensors(device_path);
       create_webpage_index();
@@ -561,20 +570,27 @@ int main(int argc, char **argv)
     }
     tot_waited = 0;
 
-    if(!(found_fuse = find_fusedev(owfs_dir, device_path, uncached_device_path))) {
-      if(owfs_dir[0]) {
-	printf("Can't find owfs/fuse directory at [%s]\n", owfs_dir);
-      } else {
-	printf("Can't find owfs/fuse directory in /proc/mounts\n");
+
+    if(!*owshell_path) {
+      if(!(found_fuse = find_fusedev(owfs_dir, device_path, uncached_device_path))) {
+	if(owfs_dir[0]) {
+	  printf("Can't find owfs/fuse directory at [%s]\n", owfs_dir);
+	} else {
+	  printf("Can't find owfs/fuse directory in /proc/mounts\n");
+	}
+	nr_errors++;
+	continue;
       }
-      nr_errors++;
-      continue;
     }
 
     tnow = time(NULL);
     if(tnow > next_scanbus) {
       /* scan bus for new devices every 5 minutes */
-      nr_sensors = scan_bus(uncached_device_path);
+      if(*owshell_path) {
+	nr_sensors = owshell_scan_bus(uncached_device_path);
+      } else {
+	nr_sensors = scan_bus(uncached_device_path);
+      }
       if(new_device_found) {
 	new_device_found = 0;
 	generate_templates = 1;
